==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GridSelectedCellRangesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellRangesChangedEventArgsDescription } from "./GridSelectedCellRangesChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectedCellRangesChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectedCellRangesChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectedCellRangesChangedEventArgsDescriptionMetadata.c(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
            a.item("AddedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
            a.item("RemovedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
            a.item("UpdatedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        }
        static d(a) {
            GridSelectedCellRangesChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridSelectedCellRangesChangedEventArgs", () => new GridSelectedCellRangesChangedEventArgsDescription());
            a.z("GridSelectedCellRangesChangedEventArgs", GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSelectedCellRangesChangedEventArgsDescriptionMetadata, 'GridSelectedCellRangesChangedEventArgsDescriptionMetadata');
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellRangesChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridSelectedCellRangesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellRangesChangedEventArgsDescription } from "./GridSelectedCellRangesChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectedCellRangesChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectedCellRangesChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectedCellRangesChangedEventArgsDescriptionMetadata.c(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
            a.item("AddedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
            a.item("RemovedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
            a.item("UpdatedRanges", "Collection:CellRange:GridSelectedCellRangesCollection:CellRange");
        }
        static d(a) {
            GridSelectedCellRangesChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridSelectedCellRangesChangedEventArgs", () => new GridSelectedCellRangesChangedEventArgsDescription());
            a.ab("GridSelectedCellRangesChangedEventArgs", GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSelectedCellRangesChangedEventArgsDescriptionMetadata, 'GridSelectedCellRangesChangedEventArgsDescriptionMetadata');
    GridSelectedCellRangesChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellRangesChangedEventArgsDescriptionMetadata;
})();
